@@ -14,13 +14,9 @@ from moto.core.exceptions import JsonRESTError
 from requests.models import CaseInsensitiveDict
 from requests.models import Response as RequestsResponse
 
+from localstack.aws.accounts import get_aws_account_id
 from localstack.config import DEFAULT_ENCODING
-from localstack.constants import (
-    APPLICATION_JSON,
-    HEADER_CONTENT_TYPE,
-    MOTO_ACCOUNT_ID,
-    TEST_AWS_ACCOUNT_ID,
-)
+from localstack.constants import APPLICATION_JSON, HEADER_CONTENT_TYPE
 from localstack.utils.aws import aws_stack
 from localstack.utils.http import replace_response_content
 from localstack.utils.json import json_safe
@@ -34,8 +30,6 @@ from localstack.utils.strings import (
 
 REGEX_FLAGS = re.MULTILINE | re.DOTALL
 
-AWS_BINARY_DATA_TYPE_STRING = 7
-
 
 class ErrorResponse(Exception):
     def __init__(self, response):
@@ -404,7 +398,13 @@ def calculate_crc32(content):
     return crc32(to_bytes(content)) & 0xFFFFFFFF
 
 
+# TODO Remove this constant with the function below
+AWS_BINARY_DATA_TYPE_STRING = 7
+
+
 def convert_to_binary_event_payload(result, event_type=None, message_type=None):
+    # TODO This encoding has been migrated to the ASF Serializer.
+    #  Remove this function after S3 and Kinesis have been migrated to ASF.
     # e.g.: https://docs.aws.amazon.com/AmazonS3/latest/API/RESTSelectObjectAppendix.html
     # e.g.: https://docs.aws.amazon.com/transcribe/latest/dg/event-stream.html
 
@@ -425,7 +425,10 @@ def convert_to_binary_event_payload(result, event_type=None, message_type=None):
         headers += header_value
 
     # construct body
-    body = bytes(result, DEFAULT_ENCODING)
+    if isinstance(result, str):
+        body = bytes(result, DEFAULT_ENCODING)
+    else:
+        body = result
 
     # calculate lengths
     headers_length = len(headers)
@@ -468,7 +471,7 @@ class MessageConversion:
 
     @staticmethod
     def fix_account_id(response):
-        return aws_stack.fix_account_id_in_arns(response, replace=TEST_AWS_ACCOUNT_ID)
+        return aws_stack.fix_account_id_in_arns(response, replace=get_aws_account_id())
 
     @staticmethod
     def fix_error_codes(method, data, response):
@@ -499,15 +502,3 @@ class MessageConversion:
             response._content = re.sub(
                 regex_false, replace_false, to_str(response.content), flags=REGEX_FLAGS
             )
-
-    @staticmethod
-    def _reset_account_id(data):
-        """Fix account ID in request payload. All external-facing responses contain our
-        predefined account ID (defaults to 000000000000), whereas the backend endpoint
-        from moto expects a different hardcoded account ID (123456789012)."""
-        return aws_stack.fix_account_id_in_arns(
-            data,
-            colon_delimiter="%3A",
-            existing=TEST_AWS_ACCOUNT_ID,
-            replace=MOTO_ACCOUNT_ID,
-        )
