@@ -96,7 +96,21 @@ class CmdDockerClient(ContainerClient):
             else:
                 raise ContainerException(
                     "Docker process returned with errorcode %s" % e.returncode, e.stdout, e.stderr
-                )
+                ) from e
+
+    def restart_container(self, container_name: str, timeout: int = 10) -> None:
+        cmd = self._docker_cmd()
+        cmd += ["restart", "--time", str(timeout), container_name]
+        LOG.debug("Restarting container with cmd %s", cmd)
+        try:
+            run(cmd)
+        except subprocess.CalledProcessError as e:
+            if "No such container" in to_str(e.stdout):
+                raise NoSuchContainer(container_name, stdout=e.stdout, stderr=e.stderr)
+            else:
+                raise ContainerException(
+                    "Docker process returned with errorcode %s" % e.returncode, e.stdout, e.stderr
+                ) from e
 
     def pause_container(self, container_name: str) -> None:
         cmd = self._docker_cmd()
@@ -110,7 +124,7 @@ class CmdDockerClient(ContainerClient):
             else:
                 raise ContainerException(
                     "Docker process returned with errorcode %s" % e.returncode, e.stdout, e.stderr
-                )
+                ) from e
 
     def unpause_container(self, container_name: str) -> None:
         cmd = self._docker_cmd()
@@ -124,7 +138,7 @@ class CmdDockerClient(ContainerClient):
             else:
                 raise ContainerException(
                     "Docker process returned with errorcode %s" % e.returncode, e.stdout, e.stderr
-                )
+                ) from e
 
     def remove_image(self, image: str, force: bool = True) -> None:
         cmd = self._docker_cmd()
@@ -140,7 +154,7 @@ class CmdDockerClient(ContainerClient):
             else:
                 raise ContainerException(
                     "Docker process returned with errorcode %s" % e.returncode, e.stdout, e.stderr
-                )
+                ) from e
 
     def commit(
         self,
@@ -161,7 +175,7 @@ class CmdDockerClient(ContainerClient):
             else:
                 raise ContainerException(
                     "Docker process returned with errorcode %s" % e.returncode, e.stdout, e.stderr
-                )
+                ) from e
 
     def remove_container(self, container_name: str, force=True, check_existence=False) -> None:
         if check_existence and container_name not in self.get_running_container_names():
@@ -179,7 +193,7 @@ class CmdDockerClient(ContainerClient):
             else:
                 raise ContainerException(
                     "Docker process returned with errorcode %s" % e.returncode, e.stdout, e.stderr
-                )
+                ) from e
 
     def list_containers(self, filter: Union[List[str], str, None] = None, all=True) -> List[dict]:
         filter = [filter] if isinstance(filter, str) else filter
@@ -198,10 +212,13 @@ class CmdDockerClient(ContainerClient):
         except subprocess.CalledProcessError as e:
             raise ContainerException(
                 "Docker process returned with errorcode %s" % e.returncode, e.stdout, e.stderr
-            )
+            ) from e
         container_list = []
         if cmd_result:
-            container_list = [json.loads(line) for line in cmd_result.splitlines()]
+            if cmd_result[0] == "[":
+                container_list = json.loads(cmd_result)
+            else:
+                container_list = [json.loads(line) for line in cmd_result.splitlines()]
         result = []
         for container in container_list:
             result.append(
@@ -228,7 +245,7 @@ class CmdDockerClient(ContainerClient):
                 raise NoSuchContainer(container_name)
             raise ContainerException(
                 f"Docker process returned with errorcode {e.returncode}", e.stdout, e.stderr
-            )
+            ) from e
 
     def copy_from_container(
         self, container_name: str, local_path: str, container_path: str
@@ -243,7 +260,7 @@ class CmdDockerClient(ContainerClient):
                 raise NoSuchContainer(container_name)
             raise ContainerException(
                 "Docker process returned with errorcode %s" % e.returncode, e.stdout, e.stderr
-            )
+            ) from e
 
     def pull_image(self, docker_image: str) -> None:
         cmd = self._docker_cmd()
@@ -256,7 +273,7 @@ class CmdDockerClient(ContainerClient):
                 raise NoSuchImage(docker_image)
             raise ContainerException(
                 "Docker process returned with errorcode %s" % e.returncode, e.stdout, e.stderr
-            )
+            ) from e
 
     def push_image(self, docker_image: str) -> None:
         cmd = self._docker_cmd()
@@ -329,7 +346,7 @@ class CmdDockerClient(ContainerClient):
             else:
                 raise ContainerException(
                     "Docker process returned with errorcode %s" % e.returncode, e.stdout, e.stderr
-                )
+                ) from e
 
     def stream_container_logs(self, container_name_or_id: str) -> CancellableStream:
         self.inspect_container(container_name_or_id)  # guard to check whether container is there
@@ -354,7 +371,7 @@ class CmdDockerClient(ContainerClient):
             else:
                 raise ContainerException(
                     "Docker process returned with errorcode %s" % e.returncode, e.stdout, e.stderr
-                )
+                ) from e
         image_data = json.loads(cmd_result.strip())
         return image_data
 
@@ -404,7 +421,7 @@ class CmdDockerClient(ContainerClient):
             else:
                 raise ContainerException(
                     "Docker process returned with errorcode %s" % e.returncode, e.stdout, e.stderr
-                )
+                ) from e
 
     def disconnect_container_from_network(
         self, network_name: str, container_name_or_id: str
@@ -424,7 +441,7 @@ class CmdDockerClient(ContainerClient):
             else:
                 raise ContainerException(
                     "Docker process returned with errorcode %s" % e.returncode, e.stdout, e.stderr
-                )
+                ) from e
 
     def get_container_ip(self, container_name_or_id: str) -> str:
         cmd = self._docker_cmd()
@@ -443,7 +460,7 @@ class CmdDockerClient(ContainerClient):
             else:
                 raise ContainerException(
                     "Docker process returned with errorcode %s" % e.returncode, e.stdout, e.stderr
-                )
+                ) from e
 
     def has_docker(self) -> bool:
         try:
@@ -465,7 +482,7 @@ class CmdDockerClient(ContainerClient):
                 raise NoSuchImage(image_name, stdout=e.stdout, stderr=e.stderr)
             raise ContainerException(
                 "Docker process returned with errorcode %s" % e.returncode, e.stdout, e.stderr
-            )
+            ) from e
         finally:
             Util.rm_env_vars_file(env_file)
 
@@ -558,7 +575,7 @@ class CmdDockerClient(ContainerClient):
                 raise NoSuchContainer(container_name, stdout=e.stdout, stderr=e.stderr)
             raise ContainerException(
                 "Docker process returned with errorcode %s" % e.returncode, e.stdout, e.stderr
-            )
+            ) from e
 
     def _build_run_create_cmd(
         self,
